@@ -3,7 +3,7 @@ from fakts import Fakts
 from herre.grants.oauth2.refresh import RefreshGrant
 from herre.fakts.fakts_endpoint_fetcher import FaktsUserFetcher
 from herre.fakts.grant import FaktsGrant
-from arkitekt_next.model import User
+from arkitekt_next.base_models import User
 from arkitekt_next.apps.service.grant_registry import ARKITEKT_GRANT_REGISTRY
 
 
