@@ -1,5 +1,6 @@
 from enum import Enum
 from qtpy import QtWidgets, QtGui, QtCore
+from arkitekt_next.qt.types import QtApp
 from koil.qt import async_to_qt
 
 from arkitekt_next.apps.types import App
@@ -62,7 +63,9 @@ class Logo(QtWidgets.QWidget):
                     data = await resp.read()
                     return data
                 else:
-                    print(f"Failed to download the image. Status code: {resp.status}")
+                    logger.error(
+                        f"Failed to download the image. Status code: {resp.status}"
+                    )
                     return None
 
 
@@ -304,7 +307,7 @@ class MagicBar(QtWidgets.QWidget):
 
     def __init__(
         self,
-        app: App,
+        app: QtApp,
         dark_mode: bool = False,
         on_error: Optional[Callable[[Exception], None]] = None,
     ) -> None:
@@ -351,7 +354,7 @@ class MagicBar(QtWidgets.QWidget):
         self.refresh_token_task.errored.connect(self.login_errored)
         self.refresh_token_task.returned.connect(self.set_unprovided)
 
-        self.provide_task = async_to_qt(self.app.rekuest.agent.aprovide)
+        self.provide_task = async_to_qt(self.app.services.get("rekuest").agent.aprovide)
         self.provide_task.errored.connect(self.provide_errored)
         self.provide_task.returned.connect(self.set_unprovided)
 
