@@ -2,7 +2,7 @@
 assignation context"""
 
 from tqdm import tqdm as _tqdm
-from rekuest.actors.vars import current_assignation_helper
+from rekuest_next.actors.vars import current_assignation_helper
 
 
 class tqdm(_tqdm):
@@ -38,6 +38,8 @@ class tqdm(_tqdm):
         if self._assignationhelper:
             if self.last_arkitekt_next_perc + 0.05 < self.last_print_n / self.total:
                 self.last_arkitekt_next_perc = self.last_print_n / self.total
-                self._assignationhelper.progress(int(self.last_arkitekt_next_perc * 100))
+                self._assignationhelper.progress(
+                    int(self.last_arkitekt_next_perc * 100)
+                )
 
         return z
